@@ -161,13 +161,26 @@ class Chrome(selenium.webdriver.chrome.webdriver.WebDriver):
             setting it is not recommended, unless you know the implications and think
             you might need it.
         """
+        platform = sys.platform
 
-        patcher = Patcher(
-            executable_path=executable_path,
-            force=patcher_force_close,
-            version_main=version_main,
-        )
-        patcher.auto()
+        if platform.endswith("win32"):
+            file = "~/appdata/roaming/undetected_chromedriver"
+        elif platform.startswith("linux"):
+            file = "{}/.local/share/undetected_chromedriver".format(Path.home())
+        elif platform.endswith("darwin"):
+            file = "~/Library/Application Support/undetected_chromedriver"
+        else:
+            file = "~/.undetected_chromedriver"
+
+        patcher = file + '/chromedriver'
+
+        if os.path.isfile(patcher) is not True:
+            patcher = Patcher(
+                executable_path=executable_path,
+                force=patcher_force_close,
+                version_main=version_main,
+            )
+            patcher.auto()
 
         if not options:
             options = ChromeOptions()
@@ -314,8 +327,12 @@ class Chrome(selenium.webdriver.chrome.webdriver.WebDriver):
         #     close_fds=IS_POSIX,
         # )
 
+        try:
+            executable_path = patcher.executable_path
+        except:
+            executable_path = patcher
         super(Chrome, self).__init__(
-            executable_path=patcher.executable_path,
+            executable_path=executable_path,
             port=port,
             options=options,
             service_args=service_args,
@@ -378,7 +395,7 @@ class Chrome(selenium.webdriver.chrome.webdriver.WebDriver):
                     "Page.addScriptToEvaluateOnNewDocument",
                     {
                         "source": """
-                        
+
                             Object.defineProperty(window, 'navigator', {
                                 value: new Proxy(navigator, {
                                         has: (target, key) => (key === 'webdriver' ? false : key in target),
@@ -390,7 +407,7 @@ class Chrome(selenium.webdriver.chrome.webdriver.WebDriver):
                                                 target[key]
                                         })
                             });
-                            
+
                     """
                     },
                 )
@@ -475,7 +492,7 @@ class Chrome(selenium.webdriver.chrome.webdriver.WebDriver):
                     "Page.addScriptToEvaluateOnNewDocument",
                     {
                         "source": """
-                            
+
                             Object.defineProperty(window, 'chrome', {
                                 value: new Proxy(window.chrome, {
                                         has: (target, key) => true,
@@ -569,12 +586,12 @@ class Chrome(selenium.webdriver.chrome.webdriver.WebDriver):
         if self.reactor and isinstance(self.reactor, Reactor):
             self.reactor.handlers.clear()
 
-    def set_cookie(self, cookie):
+    def set_cookie_st(self, cookie):
         self.cookie = cookie
 
         return self.cookie
 
-    def get_cookie(self, cookie):
+    def get_cookie_st(self):
         return self.cookie
 
     def set_error(self, error):
@@ -582,7 +599,7 @@ class Chrome(selenium.webdriver.chrome.webdriver.WebDriver):
 
         return self.error
 
-    def get_error(self, error):
+    def get_error(self):
         return self.error
 
     def tab_new(self, url: str):
